package se.zert.test;

import java.io.*;
import java.util.*;

import javax.naming.*;
import javax.security.auth.callback.*;
import javax.security.auth.login.*;

public class TestClient {
  public static void main(String[] argv) {
    try {
      System.setProperty("java.security.auth.login.config", "auth.conf");

      ConnectionHandler connectionHandler = new ConnectionHandler("admin", "test");
      LoginContext loginContext = new LoginContext("zert", connectionHandler);
      loginContext.login();

      System.out.println(runTest());
      
      loginContext.logout();
    } catch (Exception e) {
      e.printStackTrace();
    }
  }

  public static String runTest() throws Exception {
    Hashtable<String, String> env = new Hashtable<String, String>();
    env.put(Context.INITIAL_CONTEXT_FACTORY, "org.jboss.naming.NamingContextFactory");
    env.put(Context.PROVIDER_URL, "localhost");

    InitialContext context = new InitialContext(env);

    Test test = (Test)context.lookup("zert/TestBean/remote");

    return "Is administrator: " + test.checkRole();
  }
  
  public static class ConnectionHandler implements CallbackHandler {
    private String username;
    private String password;

    public ConnectionHandler(String username, String password) {
      super();
      this.password = password;
      this.username = username;
    }

    public void handle(Callback[] callbacks) throws IOException,
    UnsupportedCallbackException {

      for (int i = 0; i < callbacks.length; i++) {
        if (callbacks[i] instanceof NameCallback) {
          NameCallback nc = (NameCallback) callbacks[i];
          nc.setName(username);
        } else if (callbacks[i] instanceof PasswordCallback) {
          PasswordCallback pc = (PasswordCallback) callbacks[i];
          pc.setPassword(password.toCharArray());
        } else {
          throw new UnsupportedCallbackException(callbacks[i],
            "Unrecognized Callback");
        }
      }
    }
  }

}
